import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Turbine.Gameplay";
import "Zaqs.QuickChatSetup.VindarPatch";
import "Zaqs.QuickChatSetup.BaseClass";
import "Zaqs.QuickChatSetup.BaseFunc";
import "Zaqs.QuickChatSetup.ChannelPane";

debugMode = false; -- TODO: reenable debug script log in BaseFunc.lua

-- User configurable variables

channelCount = 12; -- increase this if you want more channels.
MAX_CHANNELS = 99; -- Needed in case currupt data are loaded from settings. increase if you want more!

optionWidth = 800;
optionHeight = 800;

paneWidth = 800;
paneHeight = 50;
defaultFont = Turbine.UI.Lotro.Font.Verdana12;

-- some Reused basic settings.
--shellCommandName = "qcs";
pluginRoot = "/Zaqs/QuickChatSetup/";
pluginName = "QuickChatSetup";
debugPluginName = "Q-C-S Debug";
pluginFullIdText = "";

-- Allocate the options panel and declare the array for the channel list (allocated in load function)
optionsPanel = Turbine.UI.Control();
optionsPanel:SetSize(optionWidth, optionHeight);
channelList = {};

-- Add the "List current channels" button - done the dirty way, but it works.
listBtnDummy = TButton("List Current channels",64,8,192,32);
listBtnWindow = TCmdContainer(64,8,192,32);
listBtn = TCommand(0,0,192,32);
listBtnCmd = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias,"/listchannels");

listBtnDummy:SetParent(optionsPanel);
listBtnWindow:SetParent(optionsPanel);
listBtn:SetParent(listBtnWindow);
listBtn:SetShortcut(listBtnCmd);

listBtn:SetZOrder(2);
listBtnWindow:SetOpacity(0);
listBtnWindow:SetMouseVisible(true);
listBtnWindow:SetVisible(true);

-- *************************************************
-- Plugin 
-- *************************************************
Plugins[pluginName].Load = function(self,sender,args)
	debug("@@Plugin load");
	pluginFullIdText = self:GetName() .. " v" .. self:GetVersion() .. " by " .. self:GetAuthor();
	Turbine.Shell.WriteLine("Plugin " .. pluginFullIdText);
	
	if debugMode then Turbine.Shell.WriteLine("Debug mode ON") end
	
	local cX,cY = 0,50;
	local obj = Turbine.Object();
	local nLoaded=0;
	-- Load data
	pcall(function() obj = PatchDataLoad( Turbine.DataScope.Server, pluginName)	end	);
	if obj~=nil then
		nLoaded=obj.cCount;
		if nLoaded<=MAX_CHANNELS then
			if nLoaded>channelCount then
				channelCount = nLoaded;
			end
		else
			-- Assume a number over limit means entire load section is invalid.
			nLoaded = 0;
		end
	end
	-- Setup the whole chat panel
	for i=1, channelCount do
		channelList[i] = TChanPane(cX,cY,paneWidth,paneHeight);
		cY = cY + paneHeight;
		channelList[i]:SetParent(optionsPanel);
		if nLoaded>=i then
			channelList[i].cnameEdit:SetText(obj.cName[i]);
			channelList[i].cpassEdit:SetText(obj.cPass[i]);
			channelList[i]:InitCommands();
		end
	end
	optionsPanel:SetHeight(cY + 16);
	Plugins[pluginName].GetOptionsPanel = function(self) return optionsPanel end;
end;


-- *************************************************
-- Plugin 
-- *************************************************
Plugins[pluginName].Unload = function(self,sender,args)
	debug("@@Plugin unload");
	-- Save a list of passwords
	local obj = Turbine.Object();
	obj.cCount = channelCount;
	obj.cName = {};
	obj.cPass = {};
	for i=1, channelCount do
		obj.cName[i] = channelList[i].cnameEdit:GetText();
		obj.cPass[i] = channelList[i].cpassEdit:GetText();
	end
	pcall(function() PatchDataSave( Turbine.DataScope.Server, pluginName, obj) end);
	debug(pluginFullIdText .. " has been removed!");
end;

-- End of File
